@@ -43,6 +43,7 @@ class OpenAPI:
         tags: Dict[str, TagDetail] = {},
         template_name: Literal["redoc", "swagger", "rapidoc"] = "swagger",
         template: Optional[str] = None,
+        reload: bool = True,
     ) -> None:
         if not template:
             template = (
@@ -50,6 +51,7 @@ class OpenAPI:
             ).read_text(encoding="utf8")
 
         self.html_template = template
+        self.reload = reload
 
         self.openapi = spec.OpenAPI(
             openapi="3.0.3",
@@ -245,7 +247,11 @@ class OpenAPI:
         def json_docs():
             openapi = self.create_docs(request)
             return JSONResponse(
-                openapi, headers={"hash": md5(json.dumps(openapi).encode()).hexdigest()}
+                openapi,
+                headers={
+                    "hash": md5(json.dumps(openapi).encode()).hexdigest(),
+                    "reload": str(self.reload).lower(),
+                },
             )
 
         def heartbeat():
